;+
; Mission:
;   ASO-S/HXI
; Purpose:
;   Set a series of HXI correlation constants
; Input:
;   None
; Output:
;   
; History: 
;   Weichen, 2021/6/19, Created 
;   Weichen, 2023/7, 

FUNCTION hxi_constant, $
  N_CHANNEL_MAX=n_channel_max, $
  COLLIMATOR_LENGTH=collimator_length,$
  DETECTOR_AREA=detector_area, $
  DETECTOR_NAME=detector_name, $
  DETECTOR_THICKNESS=detector_thickness,$
  DATE_REF = date_ref, $
  QL_ENERGY_BINS=ql_energy_bins

  n_channel_max_set =  1024L
  collimator_length_set = 1190.1038 ;mm
  detector_area_set = 3.8 ;cm2   diameter 2.2 cm for rear grid
  detector_name_set ='LaBr3'
  detector_thickness_set=2.  ;cm
  date_ref_set = '2018-12-31T16:00:00.000'  ;HXI Reference Date  
  ql_energy_bins_set = [10.0, 30.0, 50.0, 100.0, 150.0, 200.0, 300.0, 400.0 ]

  CASE 1 OF
    Keyword_Set( N_CHANNEL_MAX ): RETURN, n_channel_max_set
    Keyword_Set( COLLIMATOR_LENGTH ): RETURN, collimator_length_set
    Keyword_Set( DETECTOR_AREA ): RETURN, detector_area_set
    Keyword_Set( DETECTOR_NAME ): RETURN, detector_name_set
    Keyword_Set( DETECTOR_THICKNESS ): RETURN, detector_thickness_set
    Keyword_Set( DATE_REF ): RETURN, date_ref_set
    Keyword_Set( QL_ENERGY_BINS ): RETURN, ql_energy_bins_set
    ELSE:
  ENDCASE

  var = {hxi_constant}

  var.n_channel_max =  n_channel_max_set
  var.collimator_length = collimator_length
  var.detector_area = detector_area_set
  var.detector_name = detector_name_set
  var.detector_thickness = detector_thickness_set
  var.ql_energy_bins = ql_energy_bins_set

  RETURN, var

END
