;+
; Mission:
;  ASO-S/HXI
; Name:
;  HXI_TIMELAG_CALIB
;
; Purpose:
;  Get time lag for HXI data
;  
; Call sequence:
;  time = hxi_timelag_calib(otime) 
;
; Inputs:
;  otime : Time recorded in the HXI fits file
; Outputs:
;  Calibrated HXI data time information
;
;History:
;  Weichen, 2022/12/29
;  Weichen, 2024/01/08, updated dbase; return 0. for data after '01-Jan-24' (no longer need correction)
;
FUNCTION hxi_timelag_calib, otime

otime=anytim(otime)

tlagfile= concat_dir(getenv('hxi_conf'),'hxi_timelag.fits')
 if ~file_exist(tlagfile) then message, 'Cannot find HXI time lag file.'

info= mrdfits(tlagfile,1,/silent)
 rtime= info.rtime
 tlag = info.tlag

ttime = rtime + anytim(hxi_constant(/date_ref))

;if total(otime ge anytim('01-Jan-24')) then message,'No time calibration is required for data after 2024 year.',/con ;240309, YS, removed the message

tind = value_locate(ttime,otime)

return, tlag[tind] & END