;+
; Mission:
;   ASO-S/HXI
; Purpose: 
;   Find HXI different level data
; Input:
;   time  --  time for observation
; Keywords:
;   lev0c -- 
;   lev05 --
;   lev10 --
;   levQL --
;   SAS   --
;Output:
;   fileout -- path of out files
;Example:
;    hxi_find_data,'2022/09/20 09:20','2022/09/20 11:20',fileout=fileout,/lev10
;History:
;     Weichen, 2021/04/06, 
;     Weichen, 2022/02/23; add hxi_data_path
;     Weichen, 2022/08/27, add keywords SAS

PRO hxi_find_data, stime, etime,fileout=fileout, lev0c=lev0c,  $
  lev05=lev05, lev10=lev10, $
  levQL=levql, sas=sas
  
  if n_params() lt 1 then message, 'Syratx: hxi_find_data,2020/01/20 00:00..'

  if keyword_set(lev0c)+keyword_set(lev05)+keyword_set(lev10)+keyword_set(levql) GT 1 then $
    Message,'Only one type of data can be selected.',/con
  if keyword_set(lev0c)+keyword_set(lev05)+keyword_set(lev10)+keyword_set(levql) EQ 0 then lev10=1


;  input1= anytim(stime,/ex)
;  if n_params() eq  1 then etime=stime else input2=anytim(etime,/ex)
;  year_dir= trim(input1[6])
  ;mon_dir = trim(input1[5])
  ;day_dir = trim(input1[4])
  case 1 of
    keyword_set(lev0c): keynm='lev0c_'  ;path=concat_dir('$hxidata','science/lev00/det/'+ year_dir)
    keyword_set(lev05): keynm='lev05_'  ;path=concat_dir('$hxidata','science/lev05/'+ year_dir)
    keyword_set(lev10): keynm='lev10_'  ;path=concat_dir('$hxidata','science/lev10/'+ year_dir)
    keyword_set(levql): keynm='levq1_'  ; path=concat_dir('$hxidata','quicklook/levq1/FITS/'+ year_dir)
  endcase
  
  case 1 of 
    keyword_set(sas):   type='sas_'
    keyword_set(levql): type='qld_' 
         else:          type='det_'
  endcase

  
  file_gap= gt_hour(etime)- gt_hour(stime)
  ;file_nms = strarr(file_gap+1)
  fileout = strarr(file_gap+1)
  for i=0, file_gap do begin
    file_nm = strmid( time2file(anytim(stime) + 3600.d*i),0,11)
    paths=hxi_data_paths()
    files = file_search(paths, 'hxi_'+type+keynm+file_nm+'*'+'.fits',count=nfiles)
    file= hxi_get_recent_file(files)
    if nfiles ne 0 then fileout[i]=file[0] else message,'The file of hxi_'+type+keynm + file_nm+ '*.fits not found in catalog',/con
  endfor

 RETURN


END





