;+
; Mission:
;   ASO-S/HXI
;
; Puropse:
;   Check for flares within time range, and return the flare IDs.
; Input:
;   Tarray -- Time range
; Outputs:
;   flare_ids
; Example:
;   flare_ids=hxi_check_flares(['2022-09-19 22:39:10','2022-09-19 22:39:53'])
; History:
;   Weichen,  2022/08/03

Function hxi_check_flares, timerange, err_msg=err_msg

  err_msg=''
  
  if n_elements(timerange NE 2) then begin
    err_msg = 'The time range must be two elements!'
    message,err_msg ,/con
    return, -1
  endif
  
  tend= max(anytim(timerange),min=tstart)

  dir = getenv('hxi_dbase') ;230519, YS
  wfile = 'HXI_flarelist*.sav'
  path=[hxi_data_paths(),dir]
  file= file_search(path, wfile, count=nf)

  if nf eq 0 then begin
    err_msg = 'There is no flare list files in HXI dbase.'
    message, err_msg, /cont
    return,-1
  endif
  file=file[nf-1]

 
  restore, file
  
  ;help,hxi_flist,/str
  ind= where(tstart ge anytim(hxi_flist.startt) XOR tend GE anytim(hxi_flist.startt), nn)

  if nn eq 0 then begin
    print, 'Cant find the flare between '+ anytim(tstart,/ecs) +' and '+ anytim(tend,/ecs)
    return, -1
  endif
  
  print, 'There found '+ trim(nn) +' events between ' + anytim(tstart,/ecs) +' and '+ anytim(tend,/ecs)
  flare_ids= hxi_flist[ind].flare_id


  RETURN, flare_ids

END