;+
; MISSION:
;   ASO-S/HXI
; PURPOSE:  
;   Read default collections of count spectrum edges
; INPUTS:
;     choice   --  Which default array to chose.  For now, these are:                  
; OUTPUTS:
;     ct_edges --  (N+1) vector containing boundaries for
;                     N energy channels.
;EXAMPLE:
;      hsi_rd_ct_edges,choice,ct_edges
; HISTORY:
;   Weichen, 2022/03/02


pro hxi_rd_ct_edges,choice,ct_edges

  ; If it's already an array, return
  if (n_elements(choice) GT 1) then return

  ; Read either a named file or a coded standard file:

  if datatype(choice) EQ 'STR' then fname=choice else $
    fname='ct_edges.'+strcompress(string(choice),/remove_all)
  file= loc_file(PATH=getenv('hxi_spec'),fname)  ;230519, YS
  
  if ~file_exist(file) then message,'The file of '+fname +' is not exist!'
  
  openr,lun,/get_lun, file
  readf,lun,nedges
  ct_edges = fltarr(nedges)
  readf,lun,ct_edges
  free_lun,lun
end

