;+
; Mission     : ASO-S/HXI
; PURPOSE:
;  Define hxi_lightcurve Object
; CONTRUCTION:
;  o = Obj_New('hxi_lightcurve') or  o = hxi_lightcurve()
; HISTORY:
;  Writen by Fanxiaoyu Xia, 2021/11/27
;  2022/08/08, Fanxiaoyu Xia, added keyword spfits_str for hxi_lightcurve::getdata.
;  2022/08/12, Xiafanxiaoyu, modified titles for lightcurves.
;  2022/08/19, Fanxiaoyu Xia, added procedure hxi_lightcurve::setdata. If clicking 'Save to sav' 
;    when no lightcurve has been made, return an error.
;  2022/03/16, Fanxiaoyu Xia, added keywords tbins and evtype.
;  2022/03/27, Fanxiaoyu Xia, added keyword enebins.
;  2023/11/05, Zhentong Li, make lc of combined full open and bkg detectors seperately, 
;                           corrected the combined livetime.
;  2023/12/25, Yang Su, add exptime in output
;-

function hxi_lightcurve::getdata, time_range=time_range, collindex=collindex,$
  spfits_str=spfits_str,tbins=tbins,evtype=evtype,enebins=enebins

  if is_struct(spfits_str) eq 0 then begin
    stime=atime(time_range[0])
    etime=atime(time_range[1])
    hxi_find_data,stime,etime,fileout=filename,/lev10
    nfiles=n_elements(filename)
    nofiles=0
    for i=0,nfiles-1 do begin
      if filename[i] eq '' then begin
        nofiles=1
      endif
    endfor
    if nofiles eq 1 then return,-1
  
    if nfiles eq 1 then begin
      spfits_str= hxi_read_fits(filename,ftype='sp')
    endif else begin
      spfits_str= hxi_read_n_fits(filename,nfiles,ftype='sp')
    endelse
  endif
  
  spfits_times=spfits_str.spfits_times
  spfits_expt=spfits_str.spfits_expt
  spfits_livet = spfits_str.spfits_livet_spec
  tindex=where(spfits_times ge time_range[0] and $
  spfits_times le time_range[1])
  sptimes=spfits_times[tindex]
  splivet4fits = spfits_livet[*,tindex]
  spfits_expt=spfits_expt[tindex]
  
  if n_elements(size(enebins,/dimension)) eq 1 then begin
    data_spec=spfits_str.spfits_spdata2[*,*, tindex]
    spfitsenebins=transpose(spfits_str.spfits_spenebins)
    data=make_array(1,8, n_elements(tindex), /float)
    en_min = enebins[0]
    en_max = enebins[-1]
    en_min_index = (where( spfitsenebins[0,*] ge en_min))[0]
    en_max_index = (where( spfitsenebins[1,*] le en_max))[-1]
    en0=en_min_index<en_max_index
    en1=en_min_index>en_max_index
    data[0,*,*] =  total( data_spec[en0:en1,*,*] ,1)
  endif else if (size(enebins,/dimension))[1] eq 4 then begin
;    data1=spfits_str.spfits_lcdata1[*,*, tindex]
    data2=spfits_str.spfits_lcdata2[*,*, tindex]
    data=make_array(4, 8, n_elements(tindex), /float)
    for i=0, 7 do begin
      data[*, i, *]=data2[*, i, *]
    endfor
  endif else begin
    data_spec=spfits_str.spfits_spdata2[*,*, tindex]
    spfitsenebins=transpose(spfits_str.spfits_spenebins)
    data=make_array(n_elements(enebins[0,*]), 8, n_elements(tindex), /float)
    for j=0, n_elements(enebins[0,*])-1 do begin
      en_min = enebins[0,j]
      en_max = enebins[-1,j]
      en_min_index = (where( spfitsenebins[0,*] ge en_min))[0]
      en_max_index = (where( spfitsenebins[1,*] le en_max))[-1]
      en0=en_min_index<en_max_index
      en1=en_min_index>en_max_index
      data[j,*,*] =  total( data_spec[en0:en1,*,*] ,1)
    endfor
  endelse
  ewid = enebins[1,*]-enebins[0,*]

  if keyword_set(tbins) and tbins ne 0.25 then begin
    ;datastr={ttime:sptimes, exptime:spfits_expt, counts:data, ltime:splivet4fits} 
   
    szc= size(data,/dim)
    info={ttime:0d, exptime:0. ,$
        counts: fltarr(szc[0],szc[1]), $ 
        ltime: fltarr(szc[1]) }
    datastr = replicate(info,szc[2])
    datastr.ttime = sptimes
    datastr.exptime =spfits_expt
    datastr.counts = data
    datastr.ltime = splivet4fits

    outspec=HXI_REBIN_EXPTIM(datastr,timebin=tbins)
    data=outspec.counts
    sptimes=outspec.ttime
    spfits_expt = outspec.exptime   ;231225
    splivet4fits=outspec.ltime

  endif

  spind=where(collindex[0:7] eq 1)
  open_ind=where(collindex[0:2] eq 1, n_open)
  bkg_ind=where(collindex[3:7] eq 1, n_bkg)
  if spind[0] eq -1 then begin
    a = dialog_message('No detector is selected. Please select detector(s) first')
    data=-1
  endif else begin
    spec={sptimes4fits:sptimes, enebins:enebins, spec4fits:data, splivet4fits:splivet4fits }
    datasum = fltarr((size(data))[1],(size(data))[3], 2)
    if n_open ne 0 then begin
      temp_comb=hxi_combine_det_spec(spec, ebins=ebins,detectors=collindex,evtype=evtype, /for_lc)
      datasum[*,*,0] = temp_comb.data
    endif
    if n_bkg ne 0 then begin
      temp_comb=hxi_combine_det_spec(spec, ebins=ebins,detectors=collindex,evtype=evtype, /for_lc, /bkg)
      datasum[*,*,1] = temp_comb.data
    endif
  endelse

  lcstr={sptimes:sptimes,spexpt:spfits_expt, enebins:enebins, data:datasum, collindex:collindex, evtype:evtype}  ;;LZT 20231105
  return,lcstr
end

pro hxi_lightcurve::plotman,plotman_obj=plotman_obj, time_range=time_range, collindex=collindex, $
  spfits_str=spfits_str,tbins=tbins,evtype=evtype,enebins=enebins

  lcstr=self->getdata(time_range=time_range, collindex=collindex, spfits_str=spfits_str,$
    tbins=tbins,evtype=evtype,enebins=enebins)
  if not is_struct(lcstr) then begin
    a = dialog_message ('No plotman data found.')
    return
  endif
  
  if n_elements(size(lcstr.data)) lt 4 then begin
    if lcstr.data eq -1 then begin
      return
    endif
  endif
  times=lcstr.sptimes
  expt = lcstr.spexpt ;231225
  data=lcstr.data
  open_ind=where(collindex[0:2] eq 1, n_open)
  bkg_ind=where(collindex[3:7] eq 1, n_bkg)
  dim_title0=['D92','D93','D94','b1','b2','b3','b4','b5']
  dets1=n_open eq 0 ? '' :strjoin(dim_title0[open_ind],'+')
  dets2= n_bkg eq 0 ? '' :strjoin(dim_title0[bkg_ind+3],'+')
  dets=[dets1, dets2]
  nbins= n_elements(enebins) eq 2 ? 1 : (size(enebins,/dimension))[1]
  dim_id=strarr(nbins)
  data=transpose(data,[1,0,2])
;  data= nbins eq 1 ? reform(data): transpose(data,[1,0,2])

  if n_open ne 0 and n_bkg eq 0 then begin
    data=data[*,*,0]
    for i=0,nbins-1 do dim_id[i]=strmid(enebins[0,i],6,3)+' to '+strmid(enebins[1,i],6,3) + ' '+dets[0]
  endif
  if n_open eq 0 and n_bkg ne 0 then begin
    data=data[*,*,1]
    for i=0, nbins-1 do dim_id[i]=strmid(enebins[0,i],6,3)+' to '+strmid(enebins[1,i],6,3) + ' '+dets[1]
  endif 
  if n_open ne 0 and n_bkg ne 0 then begin
    data=reform(data, [(size(data))[1], (size(data))[2]*2])
;    data=[[data[*,*,0]],[data[*,*,1]]]
    dim_id=strarr(nbins, 2 )
    for k=0, 1 do begin
      for i=0,nbins-1 do dim_id[i, k]=strmid(enebins[0,i],6,3)+' to '+strmid(enebins[1,i],6,3) + ' '+dets[k]
    endfor

    dim_id=reform(dim_id, [(size(dim_id))[1]*2])
  endif

  data_obj = obj_new('utplot',times+expt/2., data,/ylog)
  data_obj -> set, dim1_id = dim_id
  type_list=['Counts','Counts s!u-1!n', 'Counts s!u-1!n keV!u-1!n cm!u-2!n']
   title_list = ['Counts vs Time', 'Count Rate vs Time', 'Count Flux vs Time']                          
  des_tmp = hxi_en2str(atime(time_range),/tim) + ' | ASO-S HXI | Light Curves -> '+ title_list[evtype]
  
  plotman_obj ->new_panel,input=data_obj, plot_type='utplot',/ylog,$
     ytitle=type_list[evtype],$
     title= 'ASO-S/HXI Light Curves:'+ blank(2)+ title_list[evtype], description = des_tmp           
  self->setdata,data_str=lcstr
end

pro hxi_lightcurve::setdata,data_str=data_str
  self.lc_str=ptr_new(data_str)
end

pro hxi_lightcurve::set, time_range=time_range, energy_bins=energy_bins, collnum=collnum, data_units=data_units,  _extra=_extra

  if keyword_set(time_range) then begin
    self.tstart=anytim(time_range[0])
    self.tend=anytim(time_range[1])
  endif

  if keyword_set(collnum) then begin
    self.collnum=ptr_new(collnum)
  endif

  if keyword_set(energy_bins) then begin
    self.energy_bins=ptr_new(energy_bins)
  endif
end

pro hxi_lightcurve__define 
    self = {hxi_lightcurve, time_range:[0.00,0.00], tstart:0.d0, tend:0.d0, collnum:ptr_new(),$
      energy_bins:ptr_new(), data_units:0, lc_str:ptr_new(0)}
end
