;+
; Mission     : ASO-S/HXI
; Name        : hxi_en2str
; Purpose     : array range values to strings.
; Category    : auxiliary code for the ASO-S/HXI software
;
; Inputs:
;           arr      - an array such as [value1,value2] for energy band or date-time values or date-time strings
;
;(keyword): tim      - treat the input params 'arr' as date-time values or date-time strings
;
;Output: strings for showing
;
;Examples & Output: 
;       arr1 = [1384168260.0 ,1384170600.0] & arr2 = ['11-Nov-22 11:12:00.000' ,'11-Nov-22 11:50:24.000']
;       hxi_en2str(arr1,/tim) or hxi_en2str(arr2,/tim)  -->   '11-Nov-22 11:12:00.000 to 11:50:24.000'    ; for date-time
;       hxi_en2str([10,300])                            -->   '10.0-300.0 keV'                            ; for energy band
;
;History:
;  2023/03/24, Fu Yu
;-

FUNCTION hxi_en2str, arr, tim=tim

if not keyword_set(tim) then begin
  en_str = strtrim(string(arr[0],format='(f10.1)'),1) + '-' + strtrim(string(arr[1],format='(f10.1)'),1)+ ' keV'
  return, en_str  
endif else begin
  arr = atime(arr)
  t1_str = arr[0] & t2_str = arr[1]
  tmp1 = atime(t1_str,/date, error=error1)
  tmp2 = atime(t2_str,/date, error=error2)
  if (error1+error2) lt 1 then begin
    
    t12_str = t1_str+' to '+t2_str
    if tmp1 eq tmp2 then t12_str = t1_str+' to '+ atime(t2_str,/time); If t1_str and t2_str are on the same day, just keep the 'hh:mm:ss' for t2_str, simplify

    return, t12_str
    
  endif else begin
    return, '!!! err time string'
  endelse
   
endelse

END