;+
; Mission     : ASO-S/HXI
; Name        : hxi_time_intervals_trans
; Purpose     : Transform the date-time string (or multi in an array/lsit) such as '11-Nov-22 11:33:00.000  to  11-Nov-22 11:33:30.000'  in the GUI xtextedit,
;          to a recognizable format and enable the date range over one day (, but the during will be restricted within 24h.).
;Category:  auxiliary code for the ASO-S/HXI software
;
;Inputs:
;          arr   - such as '11-Nov-2022 11:33:00.000  to  11-Nov-2022 11:33:30.000', or 
;                          '11-Nov-22 11:33:00.000  to  11:33:30.000', or 
;                          the array/list mentioned above
;                  the 'to' can be replaced by ','
;(keyword): 
;          str   - if arr is a string , it must be a string at present 
;Outputs:  dictionary with date-time, {t12:t12, t12_str:t12_str}    [2,n], [n]
;
;Called by:      - hxi.pro originally
;
;History:
;    2023/03/27, Fu Yu
;    2023/04/17, Fu Yu, minor change to allow the code to run for lower version of IDL
;-

FUNCTION hxi_time_intervals_trans, arr, str=str

err_msg = '!!! Error time strings. Please input again. '
int_max=24.d*3600;  restriction within 24h
len_th=16

IF keyword_set(str) THEN BEGIN
;  arr = ['11-Nov-22 11:33:00.000  to  11-Nov-22 11:33:30.000','11-Nov-22 11:33:00.000  to 11:33:30.000','11-Nov-22 11:00:00.000  to 11:33:30.000'] ; for test
;  arr = strtrim(arr.replace('to',','),2) ;230418, Fu Yu 
;  arr_tmp = strsplit(arr,',',/extract)
  
  t12=[] ;[2,n]
  t12_str=[]
  FOR i=0, n_elements(arr)-1 DO BEGIN
    tim = strsplit(arr[i],'to',/extract, /REGEX)  ;230418, Fu Yu,','-> 'to'  ;230531
    tim1=strtrim(tim[0],2) & tim2=strtrim(tim[1],2)
    
    t1 = anytim(tim1, /sec, error=error1)
    if strlen(tim2) lt len_th and error1 ne 1 then tim2 = atime(t1,/date)+' '+tim2 ; for short time string, like 11:33:30.000

    t2 = anytim(tim2, /sec, error=error2)
    
    ;------
    if (t2-t1) ge int_max then begin
      t2=t1+int_max ; Maximum within 24h
      print,'!!! Adjust the Maximum time interval within 24h.'
    endif
;    t1_str = atime(t1) & t2_str = atime(t2)             ;dd-month-yy hh:mm:ss.000
    t1_str = anytim(t1,/vms) & t2_str = anytim(t2,/vms) ;dd-month-yyyy hh:mm:ss.000
    ;stop
    t12_str_tmp = t1_str+' to '+t2_str
    if atime(t1_str,/date) eq atime(t2_str,/date) then t12_str_tmp = t1_str+' to '+ atime(t2_str,/time); If t1_str and t2_str are on the same day, just keep the 'hh:mm:ss' for t2_str,
    
    t12 =[[t12], [t1,t2]]           ;[2,n]
    t12_str =[t12_str,t12_str_tmp]  ;[n]    
    
    
    if error1 or error2 or (t1 gt t2) then begin
      print,err_msg
      return, {t12:-1, t12_str:'None'}
    endif
  ENDFOR
    
    ind=uniq(t12_str)
    return, {t12:t12[*,ind], t12_str:t12_str[ind]}   
  
endif else begin
  ; Nothing now.
endelse


END


