;+
; Mission: 
;    ASO-S/HXI
; Name:
;    HXI_DRM
; Purpose:
;    Read gecam detector respones matrix for OSPEX
; INPUT: 
;   files     - hxi drm files
; OUTPUT:
;   data_str  - data struct for SPEX
;   
; History:
;    2020/07/12, WeiChen, first editon
;    2022/04/06, WeiChen

pro hxi_drm, DRM_STR, $
            FILE=file, $
            ERR_CODE=err_code, $
            ERR_MSG=err_msg

    drm_str  = -1
    err_code = 0
    err_msg  = ''

  fits2rm, file, $
          RM=drm, $
          EBINS=ph_edges, $
          DETBINS=edges_out, $
          PRIMARY_HEADER=p_hdr, $
          EXT_HEADER=ext_hdr, $
          ERR_CODE=ec, $
          ERR_MSG=em

  IF EC THEN BEGIN
    err_code=1
    err_msg='Error reading the response DRM file '+file
    RETURN
  ENDIF

  sepdets     = 1
  data_name   = 'HXI'
  atten_state = -1
  detused     = FXPAR(p_hdr,'DET_NAM')
  area        = FXPAR(p_hdr,'GEOAREA')

  drm_str = { $
            EDGES_OUT : edges_out, $   ;[2,nedges_out] count energy edges in keV
            PH_EDGES  : ph_edges, $    ;[2,nedges_in] photon energy edges in keV
            AREA      : area, $        ;detector area in cm^2
            DRM       : drm, $         ;[nedges_out,nedges_in,nfilter] DRM matrix for each filter state
            SEPDETS   : sepdets, $     ;1 if separate detectors
            DATA_NAME : data_name, $   ;string name of data, e.g. 'HXI' *
            FILTER    : atten_state, $ ;[nfilter] value of filter states, or scalar -1 if doesn't apply
            DETUSED   : detused }
END

;  drm_str = { $
;    EDGES_OUT: edges_out, $ [2,nedges_out] count energy edges in keV
;    PH_EDGES: ph_edges, $ [2,nedges_in] photon energy edges in keV
;    AREA: area, $ detector area in cm^2
;    DRM: drm, $ [nedges_out,nedges_in,nfilter] DRM matrix for each filter state
;    SEPDETS: sepdets, $ 1 if separate detectors
;    DATA_NAME: data_name, $ string name of data, e.g. 'RHESSI'
;    FILTER: atten_state, $ [nfilter] value of filter states, or scalar -1 if doesn't apply
;    DETUSED: detused } string of detectors used, e.g. '1F 3F 4F 5F 6F 8F 9F'
;
;


