;+
; Mission:
;    ASO-S/HXI
; Purpose: 
;   Creates a header specific to a RATE FITS file and fills it up with default values.
; Inputs:
;   None
; Outputs:
;   rate_struct  - Structure containing RATE header related information
;
; History:
;    Weichen, 2021/07/27
;
;-

FUNCTION HXI_RATE_HEADER

  rate_struct = {rate_header}

  rate_struct.telescope = 'ASO-S'
  rate_struct.instrument = 'HXI'
  rate_struct.origin = 'HXI'
  rate_struct.timeunit = "day"
  rate_struct.timeref = "LOCAL"
  rate_struct.tassign = "SATELLITE"
  rate_struct.object = 'SUN'
  rate_struct.detchans = 0
  rate_struct.chantype = "PI"
  mjdref = anytim('00:00 1-Jan-79', /MJD)
  rate_struct.mjdref = float(mjdref.mjd)
  rate_struct.timesys = strmid(anytim('00:00 1-Jan-79', /ccsds), 0, 19)
  rate_struct.timezero = 0
  rate_struct.tstarti = 0
  rate_struct.tstartf = 0.0
  rate_struct.tstopi = 0
  rate_struct.tstopf = 0.0
  rate_struct.clockcor = 'T'
  rate_struct.telapse = 0.0
  rate_struct.poisserr = 'F'
  rate_struct.version = '1.0'
  rate_struct.observer = 'HXI'

  rate_struct.timversn = 'OGIP/93-003'

  RETURN, rate_struct

END
