;+
; Mission     : ASO-S/HXI
; Written: Fanxiaoyu Xia, 2022/08/19
pro HXI_save_spec_fits,  hxi_spec, file_out=file_out
 
  delim = path_sep()
  default, outdir, curdir() +delim   ;230531
  
  collindex=hxi_spec.collindex
  
  ind=where(collindex eq 1)
  iindbk=where(ind le 2,nbk)
  iindc=where(ind gt 2,nc)
  if n_elements(iindbk) gt 1 then begin
    bg_spec_counts=total(hxi_spec.data[*,ind[iindbk]],2)/float(nbk)
  endif else if iindbk ne -1 then begin
    bg_spec_counts=hxi_spec.data[*,ind[iindbk]]
  endif else begin
    a = dialog_message('No background detector is selected.')
    return
  endelse
  if n_elements(iindc) gt 1 then begin
    spec_counts=total(hxi_spec.data[*,ind[iindc]],2)/float(nc)
  endif else if iindc ne -1 then begin
    spec_counts=hxi_spec.data[*,ind[iindc]]
  endif else begin
    a = dialog_message('No detector is selected.')
    return
  endelse

  tarray = hxi_spec.sptimes
  enbands=hxi_spec.enebins
  den = get_edges(enbands,/width)
  drm_dia=1.
  dur= 2.
  
  n_energy = n_elements(enbands[0,*])
  
  spec_cf = spec_counts*0.
  spec_cf_bg = spec_counts*0.
  
  spec_pf = spec_counts*0.
  spec_pf_bg = spec_counts*0.

    spec_cf = ((spec_counts -bg_spec_counts)/dur)/den
    spec_cf_bg = ( bg_spec_counts/dur)/den
    
    spec_pf = ((spec_counts -bg_spec_counts)/dur)/den/drm_dia
    spec_pf_bg = ( bg_spec_counts/dur)/den/drm_dia

  hxi_spec_q2 = {   spec_cf:    fltarr(n_energy),   $
                    spec_cf_bg: fltarr(n_energy),   $
                    spec_pf:    fltarr(n_energy),   $
                    spec_pf_bg: fltarr(n_energy),   $
                    Time: ' ',                $
                    Dur: 0.,                  $
                    enbands: [0.,0.]  }
   
  nt= (size(tarray))[2]
  nen= (size(earray))[2]

  stdate= UTC2YYMMDD( anytim(tarray[0],/UTC_EXT),/yyyy )
  sttime= UTC2YYMMDD( anytim(tarray[0],/UTC_EXT),/yyyy, /HHMMSS)
  styear= STRMID(stdate,0,4)
  stmon= STRMID(stdate,4,2)

  ntime = n_elements(tarray)
  nenergy = n_elements(earray)

  this_ver =  '01'
  mk_dir, outdir+delim+styear +delim +stmon +delim+'fits'
  file_out = outdir+delim+styear +delim +stmon +delim+'fits' +delim+'hxi_evt_lev20_'+'_'+sttime+'_'+'spec'+'_v'+this_ver+'.fits'

  ;mk_fid
 
  fxhmake,header,/extend 

  fxaddpar,header,'TYPE','HXI level 2.0 SPEC FITS'
  FxAddPar,header,'MISSION','ASO-S'
  fxaddpar,header,'TELESCOP','ASO-S','Name of spacescraft'
  fxaddpar,header,'INSTRUME','HXI', 'Name of instrument'
  FxAddPar,header,'CAMERA','HXI_DET'

  FxAddPar,header,'EN_UNIT','keV'
  FxAddPar,header,'TIMEUNIT','s'

  FxAddPar,header,'OBJECT','Sun', 'Object being observed'
  FxAddPar,header,'DATE_OBS',sttime[0], 'Start nominal U.T. date of the time intervals'
  FxAddPar,header,'DATE_END',sttime[-1], 'End nominal U.T. date of the time intervals'
  ;FxAddPar,header,'FLAREID',flareid, 'HXI flare ID'
  ;FxAddPar,header,'TIMESYS','1979.00','Reference Time'
 
  FxAddPar,header,'NX',nen,'Number of energy bands'
  FxAddPar,header,'NY',nt,'Number of time intervals'
  FxAddPar,header,'WAVELNTH','X-ray'
  
  GET_DATE,cdate,/timetag
  FxAddPar,header,'DATE', cdate,'File creation date (YYYY-MM-DDThh:mm:ss UT)'

  mwrfits,0,file_out ,header,/CREATE, /silent

  ;ext =1
  fxhmake,header1,/XTENSION
  fxaddpar,header1,'EXTNAME','SPEC','HXI level 2.0 spec'
  mwrfits,hxi_spec_q2,file_out,header1
  
  hxi_d2= { enbands: fltarr(2) }
  hxi_d2  = replicate(  hxi_d2, n_energy)
  hxi_d2.enbands = enbands
  
      ;ext =2+
  fxhmake,header2,/XTENSION
  fxaddpar,header2,'EXTNAME','Enbands','Energy bands for quciklook spec'
  mwrfits,hxi_d2,file_out,header2
  
  hxi_d3= { resp: drm_dia }

  ;ext =2+
  fxhmake,header3,/XTENSION
  fxaddpar,header3,'EXTNAME','HXI Resp','Dia. response used for semi-calibration'
  mwrfits,hxi_d3,file_out,header3

end