;+
; Mission     : ASO-S/HXI
; NAME:
;     DETWIDGET
;
; Puropse:
;     Generate a dialog box that enable the user to select collimators (detectors) conveniently
;
; INPUTS: 
;     GROUP_LEADER - parent ID
; 
; OPTIONAL INPUTS:
;     DET_IDS - a binary array containing 91 elements, corresponding to 91 detectors.  0 / 1 - (not) selected     
;     MESSAGE - label info
;     
; OUTPUTS:
;     DET_IDS - a binary array containing 91 elements, corresponding to 91 detectors. 0 / 1 - (not) selected 
;
; NOTE:
;     The g1 to g10 buttons are only used to quickly select all (or none) the detectors in this group. 
;     The final return is a binary array of 91 detectors, excluding the group. 
;     So just consider whether 91 detectors are selected or not.
;
; History:
;     Written by Chang-xue Chen, 2023/03/24
;

pro detwidget_event, event
  widget_control,event.top, get_uvalue = state
  
  widget_control,event.id,get_uvalue = uvalue
  
  if strlen(uvalue) gt 2 then begin
    case uvalue of 
      '101':begin
          (*state.det_default)[0:8] = event.select
          (*state.det_ids)[0:7] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end
      '102':begin
          (*state.det_default)[9:19] = event.select
          (*state.det_ids)[8:17] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end
      '103':begin
          (*state.det_default)[20:30] = event.select
          (*state.det_ids)[18:27] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end
      '104':begin
          (*state.det_default)[31:41] = event.select
          (*state.det_ids)[28:37] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end 
      '105':begin
          (*state.det_default)[42:52] = event.select
          (*state.det_ids)[38:47] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end
      '106':begin
          (*state.det_default)[53:63] = event.select
          (*state.det_ids)[48:57] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end  
      '107':begin
          (*state.det_default)[64:74] = event.select
          (*state.det_ids)[58:67] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end
      '108':begin
          (*state.det_default)[75:85] = event.select
          (*state.det_ids)[68:77] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end
      '109':begin
          (*state.det_default)[86:92] = event.select
          (*state.det_ids)[78:83] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end
      '110':begin
          (*state.det_default)[93:100] = event.select
          (*state.det_ids)[84:90] = event.select
          for i = 0,100 do widget_control,state.w_segs[i], set_button = (*state.det_default)[i]
          widget_control, event.top, set_uvalue=state
        end
      'CANCEL':begin
        widget_control,event.top,/destroy
        *state.error =1
        end
      'READY':begin
        widget_control,event.top,/destroy
        *state.error = 0
        end
        
    endcase
  endif 
  if strlen(uvalue) le 2 then begin
    num=fix(uvalue)
    (*state.det_ids)[num-1] = event.select
    widget_control, event.top, set_uvalue=state
  endif
    
end


pro detwidget,det_ids,group_leader = group,message = message

  if not have_windows() then begin
    message,'widgets are unavailable'
    return
  endif

  device,get_screen_size=sc
  fspace = .0146*sc(0)*.5
  fxpad = .0117*sc(0)*.5
  fypad = .0146*sc(1)*.5
  xsize =  .08*sc(0)

  btitle = ' WIDGET DIAL-COLLIMATORS '
  modal=1

  w_base = widget_base(TITLE = btitle, /colum,/frame, modal=modal, group_leader=group)
  base2 = widget_base(w_base,/colum)
  ;1st row----
  if not keyword_set(message) then message = 'SELECT SUB-COLLIMATORS:'
  row0 = widget_base(base2,/column)
  wlabel = widget_label(row0,value = message)

  ;2-11th row----
  w_segs =lonarr(101)
  g1 = ['G1(3.1")','d1', 'd2', 'd3','d4','d5','d6','d7','d8']                   & uval1 = ['101','1','2','3','4','5','6','7','8']
  g2 = ['G2(4.5")','d9', 'd10','d11','d12','d13','d14','d15','d16','d17','d18'] & uval2 = ['102','9', '10','11','12','13','14','15','16','17','18']
  g3 = ['G3(6.5")','d19','d20','d21','d22','d23','d24','d25','d26','d27','d28'] & uval3 = ['103','19','20','21','22','23','24','25','26','27','28']
  g4 = ['G4(9.3")','d29','d30','d31','d32','d33','d34','d35','d36','d37','d38'] & uval4 = ['104','29','30','31','32','33','34','35','36','37','38']
  g5 = ['G5(13.4")','d39','d40','d41','d42','d43','d44','d45','d46','d47','d48'] & uval5 = ['105','39','40','41','42','43','44','45','46','47','48']
  g6 = ['G6(19.3")','d49','d50','d51','d52','d53','d54','d55','d56','d57','d58'] & uval6 = ['106','49','50','51','52','53','54','55','56','57','58']
  g7 = ['G7(29.6")','d59','d60','d61','d62','d63','d64','d65','d66','d67','d68'] & uval7 = ['107','59','60','61','62','63','64','65','66','67','68']
  g8 = ['G8(45.1")','d69','d70','d71','d72','d73','d74','d75','d76','d77','d78'] & uval8 = ['108','69','70','71','72','73','74','75','76','77','78']
  g9 = ['G9(68.8")','d79','d80','d81','d82','d83','d84']                         & uval9 = ['109','79','80','81','82','83','84']
  g10 =['G10(105.2")','d85','d86','d87','d88','d89','d90','d91']                  & uval10 = ['110','85','86','87','88','89','90','91']

  row1 = widget_base(base2,/row,/frame,/nonexclusive)

  for i=0,8 do begin
    if i eq 0 then begin
      w_segs[i]= widget_button(row1, value=g1[i], uvalue=uval1[i],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row1, value=g1[i], uvalue=uval1[i])
    endelse
  endfor

  row2 = widget_base(base2,/row,/frame,/nonexclusive)
  for i=9,19 do begin
    if i eq 9 then begin
      w_segs[i]= widget_button(row2, value=g2[i-9], uvalue=uval2[i-9],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row2, value=g2[i-9], uvalue=uval2[i-9])
    endelse

  endfor

  row3 = widget_base(base2,/row,/frame,/nonexclusive)
  for i=20,30 do begin
    if i eq 20 then begin
      w_segs[i]= widget_button(row3, value=g3[i-20], uvalue=uval3[i-20],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row3, value=g3[i-20], uvalue=uval3[i-20])
    endelse

  endfor

  row4 = widget_base(base2,/row,/frame,/nonexclusive)
  for i=31,41 do begin
    if i eq 31 then begin
      w_segs[i]= widget_button(row4, value=g4[i-31], uvalue=uval4[i-31],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row4, value=g4[i-31], uvalue=uval4[i-31])
    endelse

  endfor

  row5 = widget_base(base2,/row,/frame,/nonexclusive)
  for i=42,52 do begin
    if i eq 42 then begin
      w_segs[i]= widget_button(row5, value=g5[i-42], uvalue=uval5[i-42],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row5, value=g5[i-42], uvalue=uval5[i-42])
    endelse
  endfor

  row6 = widget_base(base2,/row,/frame,/nonexclusive)
  for i=53,63 do begin
    if i eq 53 then begin
      w_segs[i]= widget_button(row6, value=g6[i-53], uvalue=uval6[i-53],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row6, value=g6[i-53], uvalue=uval6[i-53])
    endelse
  endfor

  row7 = widget_base(base2,/row,/frame,/nonexclusive)
  for i=64,74 do begin
    if i eq 64 then begin
      w_segs[i]= widget_button(row7, value=g7[i-64], uvalue=uval7[i-64],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row7, value=g7[i-64], uvalue=uval7[i-64])
    endelse
  endfor

  row8 = widget_base(base2,/row,/frame,/nonexclusive)
  for i=75,85 do begin
    if i eq 75 then begin
      w_segs[i]= widget_button(row8, value=g8[i-75], uvalue=uval8[i-75],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row8, value=g8[i-75], uvalue=uval8[i-75])
    endelse
  endfor

  row9 = widget_base(base2,/row,/frame,/nonexclusive)
  for i=86,92 do begin
    if i eq 86 then begin
      w_segs[i]= widget_button(row9, value=g9[i-86], uvalue=uval9[i-86],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row9, value=g9[i-86], uvalue=uval9[i-86])
    endelse
  endfor

  row10 = widget_base(base2,/row,/frame,/nonexclusive)
  for i=93,100 do begin
    if i eq 93 then begin
      w_segs[i]= widget_button(row10, value=g10[i-93], uvalue=uval10[i-93],xsize= xsize)
    endif else begin
      w_segs[i]= widget_button(row10, value=g10[i-93], uvalue=uval10[i-93])
    endelse
  endfor

  ;12th row -----
  row12 = widget_base(base2, /row, space=3.*fspace, xpad=10*fxpad, ypad=fypad)
  cancel = widget_button(row12,value='           CANCEL          ', $
    uvalue='CANCEL', /no_release)
  ready = widget_button(row12,value='           READY           ',uvalue='READY', $
    /no_release)


  ;default----------------
  if not keyword_set(det_ids) then begin
    det_default =replicate(0,101)
    det_default[20:74] = 1
    det_ids = lonarr(91)
    det_ids[18:67] = 1

  endif else begin
    if n_elements(det_ids) ne 91 then begin
      a = dialog_message('The detector array needs to contain 91 elements (0/1)')
      return
    endif
    index = where(det_ids eq 1,nind)
    det_default = replicate(0,101)
    for i = 0, nind-1 do begin
      case 1 of
        index[i] lt 8: begin
          det_default[index[i]+1]=1
          end
        (index[i]-7) lt 77 :begin
          int=(index[i]-7)/10
          rem = (index[i]-7) mod 10
          if rem eq 0 then rem=-1
          det_default[8+rem+int*11+1]=1
        end
        index[i] le 90:begin
          sub =  index[i] - 83
          det_default[93+sub] = 1
        end
      endcase
    endfor
  endelse
  
  ;230601, YS
  if total(det_default[1:8]) eq 8 then det_default[0]= 1
  temp_detarray = reform(det_default[9:85], 11,7)
  indicator = total(temp_detarray[ 1:*,*],1)
  find10 = where(indicator eq 10)
  if find10[0] ne -1 then det_default[9+find10*11] = 1
  if total(det_default[87:92]) eq 6 then det_default[86]= 1
  if total(det_default[94:100]) eq 7 then det_default[93]= 1
 
  ids_default = det_ids
  error = 0
  ;------------------------
  state= { w_base: w_base, w_segs: w_segs, det_default:ptr_new(det_default),det_ids:ptr_new(det_ids),error:ptr_new(error)}

  widget_control,w_base,set_uvalue = state
  widget_control,w_base,/realize
  for i = 0,100 do begin
    widget_control, w_segs[i], set_button = det_default[i]
  endfor

  xmanager, 'detwidget', w_base, group_leader=group,/no_block


  det_ids = *state.det_ids
  if *state.error  then det_ids = ids_default


end

