;+
; Mission : ASO-S/HXI
; Puropse:
; Generate composite components that enable users to select spectral time intervals
; input:
; parent - widget id of widget calling hxi_cw_ut_range2
; Outputs:
; uvalue - user value to assign to compound widget
; History:
; Writen by Fanxiaoyu Xia, 2022/03/31

pro hxi_cw_ut_range_set_value2, id, value

  stash = widget_info ( id, /child )
  widget_control, stash, get_uvalue=state, /no_copy

  state.value = anytim( value, /sec)
  dur = state.value[1] - state.value[0]

  ; if time < 3.e7 (~1980/1/1), then probably is a relative time, not absolute, so print blanks
  if value[0] gt 3.e7 then $
    stime = anytim( value[0], /vms, truncate=state.nomsec ) else $
    stime = string(bytarr(23) + 32b)
  widget_control, state.w_start_text, set_val=stime

  ; if time < 3.e7 (~1980/1/1), then probably is a relative time, not absolute, so print blanks
  if value[1] gt 3.e7 then $
    etime = anytim( value[1], /vms, truncate=state.nomsec ) else $
    etime = string(bytarr(23) + 32b)
  widget_control, state.w_end_text, set_val=etime
  widget_control, stash, set_uvalue=state, /no_copy

end


function hxi_cw_ut_range_get_value2, id

  stash = widget_info ( id, /child )
  widget_control, stash, get_uvalue=state, /no_copy
  widget_control, state.w_start_text, get_value=time1
  widget_control, state.w_end_text, get_value=time2
  state.value = anytim( [time1, time2], /sec )
  ret = state.value
  widget_control, stash, set_uvalue=state, /no_copy

  return, ret
end

function hxi_cw_ut_range2_event, event

  struct_name = tag_names (event, /struct)
  if struct_name eq 'WIDGET_KBRD_FOCUS' then if event.enter eq 1 then return, 0

  base = event.handler
  stash =  widget_info(base, /child)

  widget_control, stash, get_uvalue=state
  old_value = state.value

  widget_control, event.id, get_uvalue=uvalue
  widget_control, state.base, get_value=value

  state.value = value
  err_msg = ''

  case uvalue of

    'tstarttime': begin
      state.value = value
    end
    
    'tendtime': begin
      state.value = value
    end

  endcase

  if err_msg ne '' then begin
    xmessage,['Error in times selected.', $
      ' ', $
      err_msg], $
      /register, group=event.top, xoff=50, yoff=50
  endif

  widget_control, state.base, set_value=state.value

  if total(abs(state.value - old_value)) ne 0. then ret = {id: base, top: event.top, handler: 0L, value: state.value}

  widget_control, stash, set_uvalue = state
  return,ret

end


function hxi_cw_ut_range2, parent, uvalue=uvalue, label=label, value=value, $
  narrow=narrow, nomsec=nomsec, $
  _extra=_extra

  checkvar, value, anytim( /sec, ['2022/09/21,02:00:00','2022/09/21,03:00:00'] )
  value = anytim(value)  
  checkvar, nomsec, 0
  checkvar, uvalue, 0
  format = '(f9.3)'

  base = widget_base( parent, uvalue=uvalue, /column, /base_align_left, $
    space=0, xpad=0, ypad=0, /frame, $
    event_func='hxi_cw_ut_range2_event', $
    func_get_value = "hxi_cw_ut_range_get_value2", $
    pro_set_value = "hxi_cw_ut_range_set_value2", $
    _extra=_extra )

  base0 = widget_base(base, /column)

  base_label = widget_base( base0, /column, /align_left )

  w_label = widget_label( base_label, value=label )

  base_vals = widget_base( base0, /column )

  base_stimes = widget_base( base_vals, /row, space=0 )

  stime_st = anytim(value[0], /vms, truncate=nomsec )
  w_start_text = widget_text( base_stimes, $
    value = stime_st, $
    xsize = strlen( stime_st ), $
    uvalue = 'tstarttime', $
    /editable, $
    /kbrd_focus_events )
    
  w_label2 = widget_label( base_stimes, value=' to ' )

  etime_st = anytim(value[1], /vms, truncate=nomsec )
  w_end_text = widget_text( base_stimes, $
    value = etime_st, $
    xsize=strlen( etime_st ), $
    uvalue = 'tendtime', $
    /editable, $
    /kbrd_focus_events )

  state = { base: base, $
    w_start_text: w_start_text, $
    w_end_text: w_end_text, $
    format: format, $
    nomsec: nomsec, $
    orig_value: value, $
    value: value }

  widget_control, widget_info( base, /child ), set_uvalue=state
  return, base

end



